#ifndef NT2_INCLUDE_CONSTANTS_FACT_4_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_FACT_4_HPP_INCLUDED

#include <nt2/constant/include/constants/fact_4.hpp>

#endif
